@@ -24,7 +24,7 @@ DepModel<-function(InVVTestindex, keindex)
                 }
   else {
   if (pick == 4){
-      cat("\nBye~~ \n\n")
+      cat("\nThanks for using ivivc for R.  Bye now. \n\n")
                 }  
       }
      }
